@@ -2,6 +2,10 @@ import nice_prompts
 
 n = nice_prompts.NicePrompt()
 
+print(n.number(float, 0, 1))
+
+print(n.number(int, 0, 100))
+
 print(n.selection({"I like pizza": "Good taste",
     "I respectfully disagree with the opinion of liking pizza": "Fair enough, good day",
     "I hate pizza": "Bad sport 👎"})) # Select one from the keys, return the value
